@@ -3,7 +3,12 @@ import spoke
 
 
 class Client:
-    def __init__(self, conn_client_class=spoke.conn.socket.Client, conn_opts=None, on_connect=None):
+    def __init__(
+        self,
+        conn_client_class=spoke.conn.socket.Client,
+        conn_opts=None,
+        on_connect=None,
+    ):
         self._conn_client = spoke.conn.pack.Client(
             conn_client_class,
             spoke.pubsub.pack.MessagePacker,
@@ -22,17 +27,18 @@ class Client:
                         await self._on_connect(conn)
                     subs = []
                     for route in self._table.routes:
-                        subs.append(
-                            self.publish("-control/subscribe", route.channel())
-                        )
+                        subs.append(self.publish("-control/subscribe", route.channel()))
                     await asyncio.gather(*subs)
                     async for msg in conn:
-                        cbs = [d(msg) for d in self._table.get_destinations(msg.channel)]
+                        cbs = [
+                            d(msg) for d in self._table.get_destinations(msg.channel)
+                        ]
                         await asyncio.gather(*cbs)
                 except ConnectionError:
                     pass
                 finally:
                     await conn.close()
+
         self._recv_task = asyncio.create_task(_run())
 
     async def publish(self, channel, body, **head):
